/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import { CommonModule } from "@angular/common";
import { Component } from "@angular/core";
import { FormControl, ReactiveFormsModule } from "@angular/forms";
import { RouterModule } from "@angular/router";
import { ApiService } from "../../api.service";
import { ConsentComponent } from "../../consent/consent.component";
import { ErrorComponent } from "../../error/error.component";
import { CheckboxComponent } from "../../inputs/checkbox/checkbox.component";
import { MultiLineComponent }
  from "../../inputs/multi-line/multi-line.component";
import { SingleLineComponent }
  from "../../inputs/single-line/single-line.component";
import { SuccessComponent } from "../../success/success.component";
import { UserinfoComponent } from "../../userinfo/userinfo.component";

@Component({
  imports: [
    RouterModule,
    CommonModule,
    ConsentComponent,
    UserinfoComponent,
    ErrorComponent,
    ReactiveFormsModule,
    CheckboxComponent,
    SingleLineComponent,
    MultiLineComponent,
    SuccessComponent,
  ],
  selector:    "event-form",
  styleUrl:    "./event.component.css",
  templateUrl: "./event.component.html",
})
export class EventComponent {
  public loading = false;
  public error = "";
  public success = false;

  public firstName = new FormControl("");
  public lastName = new FormControl("");
  public email = new FormControl("");
  public company = new FormControl("");

  public eventDescription = new FormControl("");
  public eventTopic = new FormControl("");
  public eventLocation = new FormControl("");
  public eventDate = new FormControl("");
  public eventBudget = new FormControl("");
  public travelCovered = new FormControl(false);
  public lodgingCovered = new FormControl(false);
  public foodCovered = new FormControl(false);

  public consent = new FormControl(false);

  public constructor(private readonly apiService: ApiService) {}

  // eslint-disable-next-line complexity -- stfu
  public submit(event: MouseEvent): void {
    this.error = "";
    const { form } = event.target as HTMLButtonElement;
    const valid = form?.reportValidity();
    if (valid !== true) {
      return;
    }
    this.loading = true;

    this.apiService.
      submitEvent({
        companyName:      this.company.value ?? undefined,
        consent:          this.consent.value ?? false,
        email:            this.email.value ?? undefined,
        eventBudget:      this.eventBudget.value ?? undefined,
        eventDate:        this.eventDate.value ?? undefined,
        eventDescription: this.eventDescription.value ?? undefined,
        eventLocation:    this.eventLocation.value ?? undefined,
        eventTopic:       this.eventTopic.value ?? undefined,
        firstName:        this.firstName.value ?? undefined,
        foodCovered:      this.foodCovered.value ?? false,
        lastName:         this.lastName.value ?? undefined,
        lodgingCovered:   this.lodgingCovered.value ?? false,
        travelCovered:    this.travelCovered.value ?? false,
      }).
      then((response) => {
        if ("error" in response) {
          this.error = response.error;
          this.loading = false;
        } else {
          this.error = "";
          this.success = true;
        }
      }).
      catch(() => {
        this.error = "An error occurred while submitting the form.";
        this.loading = false;
      });
  }
}
